@@ -240,7 +240,6 @@ set_locale (GDBusProxy *proxy)
         g_object_unref (locale_settings);
 }
 
-#ifdef HAVE_IBUS
 static gboolean
 is_program_in_path (const char *binary)
 {
@@ -253,29 +252,14 @@ is_program_in_path (const char *binary)
 	return TRUE;
 }
 
-static gboolean
-keyboard_plugin_is_enabled (void)
-{
-        GSettings *settings;
-        gboolean enabled;
-
-        settings = g_settings_new ("org.gnome.settings-daemon.plugins.keyboard");
-        enabled = g_settings_get_boolean (settings, "active");
-        g_object_unref (settings);
-
-        return enabled;
-}
-
 static void
 set_legacy_ibus_env_vars (GDBusProxy *proxy)
 {
-        if (is_program_in_path ("ibus-daemon") &&
-            keyboard_plugin_is_enabled ()) {
+        if (is_program_in_path ("ibus-daemon")) {
                 set_session_env (proxy, "QT_IM_MODULE", "ibus");
                 set_session_env (proxy, "XMODIFIERS", "@im=ibus");
         }
 }
-#endif
 
 static void
 register_with_gnome_session (GDBusProxy *proxy)
@@ -315,9 +299,8 @@ name_acquired_handler (GDBusConnection *connection,
         /* Always call this first, as Setenv can only be called before
            any client registers */
         set_locale (proxy);
-#ifdef HAVE_IBUS
         set_legacy_ibus_env_vars (proxy);
-#endif
+
         start_settings_manager ();
         register_with_gnome_session (proxy);
         g_unix_signal_add (SIGTERM, on_term_signal, manager);
