@@ -599,6 +599,14 @@ get_window_scale (GnomeXSettingsManager *manager)
                 if (height < HIDPI_MIN_HEIGHT)
                         goto out;
 
+                /* Somebody encoded the aspect ratio (16/9 or 16/10)
+                 * instead of the physical size */
+                if ((width_mm == 160 && height_mm == 90) ||
+                    (width_mm == 160 && height_mm == 100) ||
+                    (width_mm == 16 && height_mm == 9) ||
+                    (width_mm == 16 && height_mm == 10))
+                        goto out;
+
                 window_scale = 1;
                 if (width_mm > 0 && height_mm > 0) {
                         dpi_x = (double)width / (width_mm / 25.4);
@@ -1266,8 +1274,10 @@ gnome_xsettings_manager_stop (GnomeXSettingsManager *manager)
                 g_clear_object (&manager->priv->rr_screen);
         }
 
-        if (p->shell_name_watch_id > 0)
+        if (p->shell_name_watch_id > 0) {
                 g_bus_unwatch_name (p->shell_name_watch_id);
+                p->shell_name_watch_id = 0;
+        }
 
         if (p->manager != NULL) {
                 xsettings_manager_destroy (p->manager);
@@ -1320,6 +1330,8 @@ gnome_xsettings_manager_finalize (GObject *object)
 
         g_return_if_fail (xsettings_manager->priv != NULL);
 
+        gnome_xsettings_manager_stop (xsettings_manager);
+
         if (xsettings_manager->priv->start_idle_id != 0)
                 g_source_remove (xsettings_manager->priv->start_idle_id);
 
